#
# spec file for package python-Pillow
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Pillow
Version:        2.9.0
Release:        6.4
Summary:        Python Imaging Library (Fork)
License:        HPND
Group:          Development/Languages/Python
Url:            http://python-imaging.github.io/
Source:         https://pypi.python.org/packages/source/P/Pillow/Pillow-%{version}.tar.gz
Source1:        testimages.tar.bz2
Patch0:         Pillow-overflows.patch
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  python-tk
BuildRequires:  tix
BuildRequires:  tk-devel
BuildRequires:  unzip
%if 0%{?suse_version} > 1210
BuildRequires:  libjpeg8-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libwebp-devel
%else
%if 0%{?rhel} > 6
BuildRequires:  lcms2-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  libwebp-devel
%else
BuildRequires:  python-unittest2
%endif
%endif
%if 0%{?suse_version} > 1315
BuildRequires:  openjpeg2-devel
%endif
BuildRequires:  freetype2-devel
BuildRequires:  libtiff-devel
BuildRequires:  python-nose
BuildRequires:  zlib-devel
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitearch: %global python_sitearch %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%endif
# Pillow is a friendly PIL fork which we package as 'imaging', the latter isn't obsolete though:
Conflicts:      python-imaging < %{version}
# NOTE(saschpe): python-imaging should have never provided this and I'm a bit relucatant do it either.
# http://en.opensuse.org/openSUSE:Upgrade_dependencies_explanation#Replace_a_package_by_another_with_the_same_functionality
# ALSO NOTE (frispete): without providing python-imaging, all packages requiring it will break
Provides:       python-imaging = %{version}

Obsoletes:      python-imaging-sane
Provides:       python-imaging-sane

%description
Pillow is the "friendly" PIL fork by Alex Clark and Contributors. PIL is the
Python Imaging Library by Fredrik Lundh and Contributors.

%package tk
Summary:        Python Imaging Library (Fork) - Tcl/Tk Module
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
# NOTE: We don't need to conflict with python-imaging here, 
# because this package depends on python-Pillow, which already conflicts with python-imaging,
# so this cannot be installed alongside python-imaging
# And we cannot conflict with python-imaging directly, since python-Pillow provides python-imaging
# Just in case, conflict with python-imaging-tk in case it is ever implemented.
Obsoletes:      python-imaging-tk
Provides:       python-imaging-tk

%description tk
Pillow is the "friendly" PIL fork by Alex Clark and Contributors. PIL is the
Python Imaging Library by Fredrik Lundh and Contributors.

#NOTE(saschpe): No 'sane' subpackage like "python-imaging", that stuff
# would belong into python-pysane, if anybody would care :-)

%prep
%setup -q -n Pillow-%{version}
%patch0 -p1
tar xvjf %{SOURCE1}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
for p in pilconvert pildriver pilfile pilfont pilprint ; do
  mv %{buildroot}%{_bindir}/$p.py %{buildroot}%{_bindir}/$p-%{py_ver}
  ln -s %{_bindir}/$p-%{py_ver} %{buildroot}%{_bindir}/$p
  ln -s %{_bindir}/$p-%{py_ver} %{buildroot}%{_sysconfdir}/alternatives/$p
done
# add missing path
echo "PIL" > %{buildroot}%{python_sitearch}/PIL.pth

%check
PYTHONPATH=%{buildroot}/%{python_sitearch} python selftest.py --installed
PYTHONPATH=%{buildroot}/%{python_sitearch} python test-installed.py

%post
update-alternatives \
    --install %{_bindir}/pilconvert pilconvert %{_bindir}/pilconvert-%{py_ver} 20 \
    --slave %{_bindir}/pildriver pildriver %{_bindir}/pildriver-%{py_ver} \
    --slave %{_bindir}/pilfile pilfile %{_bindir}/pilfile-%{py_ver} \
    --slave %{_bindir}/pilfont pilfont %{_bindir}/pilfont-%{py_ver} \
    --slave %{_bindir}/pilprint pilprint %{_bindir}/pilprint-%{py_ver}

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove pilconvert %{_bindir}/pilconvert-%{py_ver}
fi

%files
%defattr(-,root,root,-)
%doc CHANGES.rst README.rst
%ghost %{_bindir}/pilconvert
%{_bindir}/pilconvert-%{py_ver}
%ghost %{_bindir}/pildriver
%{_bindir}/pildriver-%{py_ver}
%ghost %{_bindir}/pilfile
%{_bindir}/pilfile-%{py_ver}
%ghost %{_bindir}/pilfont
%{_bindir}/pilfont-%{py_ver}
%ghost %{_bindir}/pilprint
%{_bindir}/pilprint-%{py_ver}
%{python_sitearch}/PIL
%{python_sitearch}/PIL.pth
%{python_sitearch}/Pillow-%{version}-py%{py_ver}.egg-info
%exclude %{python_sitearch}/PIL/ImageTk*
%exclude %{python_sitearch}/PIL/_imagingtk*
%ghost %{_sysconfdir}/alternatives/pilconvert
%ghost %{_sysconfdir}/alternatives/pildriver
%ghost %{_sysconfdir}/alternatives/pilfile
%ghost %{_sysconfdir}/alternatives/pilfont
%ghost %{_sysconfdir}/alternatives/pilprint

%files tk
%defattr(-,root,root,-)
%{python_sitearch}/PIL/ImageTk*
%{python_sitearch}/PIL/_imagingtk*

%changelog
* Tue Mar  1 2016 jmatejek@suse.com
- backport security fixes from 3.1.1 (python-Pillow-format-bugs.patch):
  * Fixed an integer overflow in Resample.c causing writes in the Python heap.
  * Fixed a buffer overflow in PcdDecode.c causing a segfault when opening
    PhotoCD files. CVE-2016-TBD
  * Fixed a buffer overflow in FliDecode.c causing a segfault when opening
    FLI files. CVE-2016-0775 (fixes bsc#965582)
  * Fixed a buffer overflow in TiffDecode.c causing an arbitrary amount of
    memory to be overwritten when opening a specially crafted invalid TIFF
    file. CVE-2016-0740 (fixes bsc#965579)sss(normaltrans, normaltrans)
* Wed Jul 29 2015 jacobwinski@gmail.com
- Update to 2.9.0:
  * Added test for GimpPaletteFile #1324
  * Fixed ValueError in Python 2.6 #1315 #1316
  * Fixed tox test script path #1308
  * Added width and height properties #1304
  * Update tiff and tk tcl 8.5 versions #1303
  * Add functions to convert: Image <-> QImage; Image <-> QPixmap #1217
  * Remove duplicate code in gifmaker script #1294
  * Multiline text in ImageDraw #1177
  * Automated Windows CI/build support #1278
  * Removed support for Tk versions earlier than 8.4 #1288
  * Fixed polygon edge drawing #1255 (fixes #1252)
  * Check prefix length in _accept methods #1267
  * Register MIME type for BMP #1277
  * Adjusted ImageQt use of unicode() for 2/3 compatibility #1218
  * Identify XBM file created with filename including underscore #1230 (fixes #1229)
  * Copy image when saving in GifImagePlugin #1231 (fixes #718)
  * Removed support for FreeType 2.0 #1247
  * Added background saving to GifImagePlugin #1273
  * Provide n_frames attribute to multi-frame formats #1261
  * Add duration and loop set to GifImagePlugin #1172, #1269
  * Ico files are little endian #1232
  * Upgrade olefile from 0.30 to 0.42b #1226
  * Setting transparency value to 0 when the tRNS contains only null byte(s) #1239
  * Separated out feature checking from selftest #1233
  * Style/health fixes
  * Update WebP from 0.4.1 to 0.4.3 #1235
  * Release GIL during image load (decode) #1224
  * Added icns save #1185
  * Fix putdata memory leak #1196
  * Keep user-specified ordering of icon sizes #1193
  * Tiff: allow writing floating point tag values #1113
- Update to 2.8.2:
  * Bug fix: Fixed Tiff handling of bad EXIF data
- Remove 0001-Ico-files-are-little-endian-ref-1204.patch: merged upstream
- Remove fix-textsize-equal.patch: merged upstream
* Mon Jul 27 2015 seife+obs@b1-systems.com
- fix build and dependencies for RHEL/CentOS 7
* Sat Jun 13 2015 dmueller@suse.com
- add 0001-Ico-files-are-little-endian-ref-1204.patch: fix for s390x
* Wed Apr 22 2015 mcihar@suse.cz
- Update to 2.8.1:
  - Bug fix: Catch struct.error on invalid JPEG, fixes #1163
  - Fix 32-bit BMP loading (RGBA or RGBX)
  - Fix UnboundLocalError in ImageFile #1131
  - Re-enable test image caching
  - Fix: Cannot identify EPS images, fixes #1104
  - Configure setuptools to run nosetests, fixes #729
  - Style/health fixes
  - Add support for HTTP response objects to Image.open()
  - Improve reference docs for PIL.ImageDraw.Draw.pieslice() #1145
  - Added copy method font_variant() and accessible properties to truetype() #1123
  - Fix ImagingEffectNoise #1128
  - Remove unreachable code
  - Let Python do the endian stuff + tests #1121
  - Fix webp decode memory leak #1114
  - Fast path for opaque pixels in RGBa unpacker #1088
  - Enable basic support for 'RGBa' raw encoding/decoding #1096
- Remove Pillow-fixtests.patch, merged upstream
* Tue Apr 21 2015 tbechtold@suse.com
- Add fix-textsize-equal.patch. Fixes testsuite on SLE11SP3
* Fri Feb  6 2015 hpj@urpla.net
- fix test for lossy webp alpha deviation of earlier lib versions
  * Add Pillow-fixtests.patch
* Thu Jan  8 2015 tbechtold@suse.com
- update to version 2.7.0:
  - Look for OSX and Linux fonts in common places. #1054
  - Fix potential PNG decompression DOS #1060
  - Use underscores, not spaces, in TIFF tag kwargs. #1044, #1058
  - Update PSDraw for Python3, add tests. #1055
- Use Bicubic filtering by default for thumbnails. Don't use Jpeg Draft mode for thumbnails. #1029
  - Fix MSVC compiler error: Use Py_ssize_t instead of ssize_t #1051
  - Fix compiler error: MSVC needs varaibles defined at the start of the block #1048
  - The GIF Palette optimization algorithm is only applicable to mode='P' or 'L' #993
  - Use PySide as an alernative to PyQt4/5.
  - Replace affine-based im.resize implementation with convolution-based im.stretch #997
  - Replace Gaussian Blur implementation with iterated fast box blur. #961  Note: Radius parameter is interpreted differently than before.
  - Better docs explaining import _imaging failure #1016, build #1017, mode #1018, PyAccess, PixelAccess objects #1019 Image.quantize #1020 and Image.save #1021
  - Fix for saving TIFF image into an io.BytesIO buffer #1011
  - Fix antialias compilation on debug versions of Python #1010
  - Fix for Image.putdata segfault #1009
  - Ico save, additional tests #1007
  - Use PyQt4 if it has already been imported, otherwise prefer PyQt5. #1003
  - Speedup resample implementation up to 2.5 times. #977
  - Speed up rotation by using cache aware loops, added transpose to rotations. #994
  - Fix Bicubic interpolation #970
  - Support for 4-bit greyscale TIFF images #980
  - Updated manifest #957
  - Fix PyPy 2.4 regression #952
  - Webp Metadata Skip Test comments #954
  - Fixes for things rpmlint complains about #942
- update to version 2.6.2:
  - Fix potential PNG decompression DOS #1060
  - Fix Regression in PyPy 2.4 in streamio  #958
* Tue Nov 18 2014 toddrme2178@gmail.com
- Update to 2.6.1
  - Fix SciPy regression for in Image.resize
  - Fix manifest to include all test files
- Update to 2.6.0
  - Relax precision of ImageDraw tests for x86, GimpGradient for PPC
  - Use redistributable image for testing
  - Use redistributable ICC profiles for testing, skip if not available
  - Additional documentation for JPEG info and save options
  - Fix JPEG Encoding memory leak when exif or qtables were specified
  - Image.tobytes() and Image.tostring() documentation update
  - On Windows, do not execute convert.exe without specifying path
  - Fix msvc build error
  - Fix for handling P + transparency -> RGBA conversions
  - Retain alpha in ImageEnhance operations
  - Jpeg2k Decode/encode memory leak fix
  - EpsFilePlugin Speed improvements
  - Don't resize if already the right size
  - Fix for reading multipage TIFFs
  - Correctly handle saving gray and CMYK JPEGs with quality=keep
  - Correct duplicate Tiff Metadata and Exif tag values
  - Windows fixes
  - Fix TGA files with image ID field
  - Fixed wrong P-mode of small, unoptimized L-mode GIF
  - Fixed CVE-2014-3598, a DOS in the Jpeg2KImagePlugin
  - Fixed CVE-2014-3589, a DOS in the IcnsImagePlugin
  - setup.py: Close open file handle before deleting
  - Return Profile with Transformed Images
  - Changed docstring to refer to the correct function
  - Adding coverage support for C code tests
  - PyPy performance improvements
  - Added support for reading MPO files
  - Added support for encoding and decoding iTXt chunks
  - HSV Support
  - Removed unusable ImagePalette.new()
  - Fix Scrambled XPM
  - Doc cleanup
  - Fix `ImageStat` docs
  - Added docs for ExifTags
  - More tests for CurImagePlugin, DcxImagePlugin, Effects.c, GimpGradientFile, ImageFont, ImageMath, ImagePalette, IptcImagePlugin, SpiderImagePlugin, SgiImagePlugin, XpmImagePlugin and _util
  - Fix return value of FreeTypeFont.textsize() does not include font offsets
  - Fix dispose calculations for animated GIFs
  - Added class checking to Image __eq__ function
  - Test PalmImagePlugin and method to skip known bad tests
- Update to 2.5.3
  - Fixed CVE-2014-3598, a DOS in the Jpeg2KImagePlugin (backport)
- Update to 2.5.2
  - Fixed CVE-2014-3589, a DOS in the IcnsImagePlugin (backport)
* Mon Aug 18 2014 mcihar@suse.cz
- Use versioned provides and conflicts to fix installation on SLE11
* Mon Aug 11 2014 mcihar@suse.cz
- enable build time testing, but not for i586 as it's broken there due to some
  rounding error (see https://github.com/python-pillow/Pillow/issues/819)
* Mon Aug 11 2014 mcihar@suse.cz
- Update to 2.5.1:
  * 2.5.1 (2014-07-10)
    Fixed install issue if Multiprocessing.Pool is not available [wiredfool]
    32bit mult overflow fix #782 [wiredfool]
  * 2.5.0 (2014-07-01)
    Imagedraw rewrite [terseus, wiredfool]
    Add support for multithreaded test execution [wiredfool]
    Prevent shell injection #748 [mbrown1413, wiredfool]
    Support for Resolution in BMP files #734 [gcq]
    Fix error in setup.py for Python 3 [matthew-brett]
    Pyroma fix and add Python 3.4 to setup metadata #742 [wirefool]
    Top level flake8 fixes #741 [aclark]
    Remove obsolete Animated Raster Graphics (ARG) support [hugovk]
    Fix test_imagedraw failures #727 [cgohlke]
    Fix AttributeError: class Image has no attribute 'DEBUG' #726 [cgohlke]
    Fix msvc warning: 'inline' : macro redefinition #725 [cgohlke]
    Cleanup #654 [dvska, hugovk, wiredfool]
    16-bit monochrome support for JPEG2000 [videan42]
    Fixed ImagePalette.save [brightpisces]
    Support JPEG qtables [csinchok]
    Add binary morphology addon [dov, wiredfool]
    Decompression bomb protection [hugovk]
    Put images in a single directory [hugovk]
    Support OpenJpeg 2.1 [al45tair]
    Remove unistd.h #include for all platforms [wiredfool]
    Use unittest for tests [hugovk]
    ImageCms fixes [hugovk]
    Added more ImageDraw tests [hugovk]
    Added tests for Spider files [hugovk]
    Use libtiff to write any compressed tiff files [wiredfool]
    Support for pickling Image objects [hugovk]
    Fixed resolution handling for EPS thumbnails [eliempje]
    Fixed rendering of some binary EPS files (Issue #302) [eliempje]
    Rename variables not to use built-in function names [hugovk]
    Ignore junk JPEG markers [hugovk]
    Change default interpolation for Image.thumbnail to Image.ANTIALIAS [hugovk]
    Add tests and fixes for saving PDFs [hugovk]
    Remove transparency resource after P->RGBA conversion [hugovk]
    Clean up preprocessor cruft for Windows [CounterPillow]
    Adjust Homebrew freetype detection logic [jacknagel]
    Added Image.close, context manager support. [wiredfool]
    Added support for 16 bit PGM files. [wiredfool]
    Updated OleFileIO to version 0.30 from upstream [hugovk]
    Added support for additional TIFF floating point format [Hijackal]
    Have the tempfile use a suffix with a dot [wiredfool]
    Fix variable name used for transparency manipulations [nijel]
- adjusted testsuite execution
* Fri Aug  1 2014 tiwai@suse.de
- Add missing PIL.pth installation (bnc#889973)
* Wed May 28 2014 toddrme2178@gmail.com
- Fixing conflicting provides/conflicts that prevent installation
  of the tk subpackage.
* Tue May 27 2014 mcihar@suse.com
- Adjust openjpeg2 dependency for older distributions
* Thu May  8 2014 hpj@urpla.net
- New upstream release 2.4.0. For details see
  https://pypi.python.org/pypi/Pillow/2.4.0
- New dependency: openjpeg2 for JPEG 2000 support
* Sun Apr 27 2014 hpj@urpla.net
- provide python-imaging in order to act as a drop in replacement
  for it.
* Fri Feb 14 2014 mcihar@suse.cz
- Fix build for older distributions which do not include lcms2
* Tue Feb  4 2014 hpj@urpla.net
- symlink alternatives files, as requested from Coolo, in order to
  get rid of suse version conditional
* Fri Jan 17 2014 hpj@urpla.net
- also exclude 12.2 from ghost etc/alternatives/* as this results in
  failed builds with: Explicit file attributes required in spec for:
  $BUILDROOT/etc/alternatives/pil*
* Tue Jan  7 2014 marko.kohtala@gmail.com
- New upstream release 2.3.0. For details see
  https://pypi.python.org/pypi/Pillow/2.3.0
- Drop use-recommended-freetype-include.patch: merged on upstream
- Build with liblcms2 instead of liblcms due to upstream switching
  library.
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Mon Nov 18 2013 speilicke@suse.com
- Move away from pkgconfig-style buildrequires to support SLE
- Implement update-alternatives
* Thu Nov 14 2013 cfarrell@suse.com
- License update: HPND
* Tue Nov 12 2013 speilicke@suse.com
- Add split-provides inside tk sub-package to get rid of python-imaging-tk
* Thu Nov  7 2013 speilicke@suse.com
- Initial version
